@@ -6,34 +6,28 @@ const File = require('./file');
 const FileDescriptor = require('./descriptor');
 const Directory = require('./directory');
 const SymbolicLink = require('./symlink');
-const FSError = require('./error');
+const {FSError} = require('./error');
 const constants = require('constants');
 const getPathParts = require('./filesystem').getPathParts;
-const bufferFrom = require('./buffer').from;
-const bufferAlloc = require('./buffer').alloc;
+
+const MODE_TO_KTYPE = {
+  [constants.S_IFREG]: constants.UV_DIRENT_FILE,
+  [constants.S_IFDIR]: constants.UV_DIRENT_DIR,
+  [constants.S_IFBLK]: constants.UV_DIRENT_BLOCK,
+  [constants.S_IFCHR]: constants.UV_DIRENT_CHAR,
+  [constants.S_IFLNK]: constants.UV_DIRENT_LINK,
+  [constants.S_IFIFO]: constants.UV_DIRENT_FIFO,
+  [constants.S_IFSOCK]: constants.UV_DIRENT_SOCKET
+};
 
 /** Workaround for optimizations in node 8+ */
 const fsBinding = process.binding('fs');
 const kUsePromises = fsBinding.kUsePromises;
 let statValues;
+let bigintStatValues;
 if (fsBinding.statValues) {
   statValues = fsBinding.statValues; // node 10+
-} else if (fsBinding.getStatValues) {
-  statValues = fsBinding.getStatValues(); // node 8
-} else {
-  statValues = [];
-}
-
-// nodejs v6,8,10 and v12 before v12.10.0 has length 28
-// nodejs v12.10.0+ has length 36
-const statContainsNs = statValues.length > 28;
-
-/** Introduction of BigUint64Array in 10.5 */
-let BigUint64Array;
-if (global.BigUint64Array) {
-  BigUint64Array = global.BigUint64Array;
-} else {
-  BigUint64Array = function() {};
+  bigintStatValues = fsBinding.bigintStatValues;
 }
 
 const MAX_LINKS = 50;
@@ -117,118 +111,24 @@ function normalizeCallback(callback) {
   return callback;
 }
 
-/**
- * Handle stat optimizations introduced in Node 8.
- * See https://github.com/nodejs/node/pull/11665.
- * @param {Function} callback The callback.
- * @return {Function} The wrapped callback.
- */
-function wrapStatsCallback(callback) {
-  if (callback && typeof callback.oncomplete === 'function') {
-    // Unpack callback from FSReqWrap
-    callback = callback.oncomplete.bind(callback);
-  }
-  if (typeof callback === 'function') {
-    return function(err, stats) {
-      if (stats) {
-        fillStatsArray(stats, statValues);
-      }
-      callback.apply(this, arguments);
-    };
-  } else {
-    return callback;
+function getDirentType(mode) {
+  const ktype = MODE_TO_KTYPE[mode & constants.S_IFMT];
+
+  if (ktype === undefined) {
+    return constants.UV_DIRENT_UNKNOWN;
   }
+
+  return ktype;
 }
 
 function notImplemented() {
   throw new Error('Method not implemented');
 }
 
-/**
- * Create a new stats object.
- * @param {Object} config Stats properties.
- * @constructor
- */
-function Stats(config) {
-  for (const key in config) {
-    this[key] = config[key];
-  }
-  // node 10 expects an array internally
-  // see https://github.com/nodejs/node/pull/19714
-  fillStatsArray(config, this);
+function deBuffer(p) {
+  return Buffer.isBuffer(p) ? p.toString() : p;
 }
 
-/**
- * Check if mode indicates property.
- * @param {number} property Property to check.
- * @return {boolean} Property matches mode.
- */
-Stats.prototype._checkModeProperty = function(property) {
-  return (this.mode & constants.S_IFMT) === property;
-};
-
-/**
- * @return {Boolean} Is a directory.
- */
-Stats.prototype.isDirectory = function() {
-  return this._checkModeProperty(constants.S_IFDIR);
-};
-
-/**
- * @return {Boolean} Is a regular file.
- */
-Stats.prototype.isFile = function() {
-  return this._checkModeProperty(constants.S_IFREG);
-};
-
-/**
- * @return {Boolean} Is a block device.
- */
-Stats.prototype.isBlockDevice = function() {
-  return this._checkModeProperty(constants.S_IFBLK);
-};
-
-/**
- * @return {Boolean} Is a character device.
- */
-Stats.prototype.isCharacterDevice = function() {
-  return this._checkModeProperty(constants.S_IFCHR);
-};
-
-/**
- * @return {Boolean} Is a symbolic link.
- */
-Stats.prototype.isSymbolicLink = function() {
-  return this._checkModeProperty(constants.S_IFLNK);
-};
-
-/**
- * @return {Boolean} Is a named pipe.
- */
-Stats.prototype.isFIFO = function() {
-  return this._checkModeProperty(constants.S_IFIFO);
-};
-
-/**
- * @return {Boolean} Is a socket.
- */
-Stats.prototype.isSocket = function() {
-  return this._checkModeProperty(constants.S_IFSOCK);
-};
-
-// I don't know exactly what is going on.
-// If _openFiles is a property of binding instance, there is a strange
-// bug in nodejs v10+ that something cleaned up this._openFiles from
-// nowhere. It happens after second mockfs(), after first mockfs()+restore().
-
-// So I moved _openFiles to a private var. The other two vars (_system,
-// _counter) do not hurt.
-// This fixed https://github.com/tschaub/mock-fs/issues/254
-// But I did not dig deep enough to understand what exactly happened.
-let _system;
-let _openFiles = {};
-let _counter = 0;
-
 /**
  * Create a new binding with the given file system.
  * @param {FileSystem} system Mock file system.
@@ -239,25 +139,31 @@ function Binding(system) {
    * Mock file system.
    * @type {FileSystem}
    */
-  _system = system;
-
-  /**
-   * Stats constructor.
-   * @type {function}
-   */
-  this.Stats = Stats;
+  this._system = system;
 
   /**
    * Lookup of open files.
    * @type {Object.<number, FileDescriptor>}
    */
-  _openFiles = {};
+  this._openFiles = {};
 
   /**
    * Counter for file descriptors.
    * @type {number}
    */
-  _counter = 0;
+  this._counter = -1;
+
+  const stdin = new FileDescriptor(constants.O_RDWR);
+  stdin.setItem(new File.StandardInput());
+  this.trackDescriptor(stdin);
+
+  const stdout = new FileDescriptor(constants.O_RDWR);
+  stdout.setItem(new File.StandardOutput());
+  this.trackDescriptor(stdout);
+
+  const stderr = new FileDescriptor(constants.O_RDWR);
+  stderr.setItem(new File.StandardError());
+  this.trackDescriptor(stderr);
 }
 
 /**
@@ -265,7 +171,7 @@ function Binding(system) {
  * @return {FileSystem} The underlying file system.
  */
 Binding.prototype.getSystem = function() {
-  return _system;
+  return this._system;
 };
 
 /**
@@ -273,7 +179,7 @@ Binding.prototype.getSystem = function() {
  * @param {FileSystem} system The new file system.
  */
 Binding.prototype.setSystem = function(system) {
-  _system = system;
+  this._system = system;
 };
 
 /**
@@ -281,34 +187,34 @@ Binding.prototype.setSystem = function(system) {
  * @param {number} fd File descriptor identifier.
  * @return {FileDescriptor} File descriptor.
  */
-function getDescriptorById(fd) {
-  if (!_openFiles.hasOwnProperty(fd)) {
+Binding.prototype.getDescriptorById = function(fd) {
+  if (!this._openFiles.hasOwnProperty(fd)) {
     throw new FSError('EBADF');
   }
-  return _openFiles[fd];
-}
+  return this._openFiles[fd];
+};
 
 /**
  * Keep track of a file descriptor as open.
  * @param {FileDescriptor} descriptor The file descriptor.
  * @return {number} Identifier for file descriptor.
  */
-function trackDescriptor(descriptor) {
-  const fd = ++_counter;
-  _openFiles[fd] = descriptor;
+Binding.prototype.trackDescriptor = function(descriptor) {
+  const fd = ++this._counter;
+  this._openFiles[fd] = descriptor;
   return fd;
-}
+};
 
 /**
  * Stop tracking a file descriptor as open.
  * @param {number} fd Identifier for file descriptor.
  */
-function untrackDescriptorById(fd) {
-  if (!_openFiles.hasOwnProperty(fd)) {
+Binding.prototype.untrackDescriptorById = function(fd) {
+  if (!this._openFiles.hasOwnProperty(fd)) {
     throw new FSError('EBADF');
   }
-  delete _openFiles[fd];
-}
+  delete this._openFiles[fd];
+};
 
 /**
  * Resolve the canonicalized absolute pathname.
@@ -322,19 +228,17 @@ Binding.prototype.realpath = function(filepath, encoding, callback, ctx) {
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
     let realPath;
-    if (Buffer.isBuffer(filepath)) {
-      filepath = filepath.toString();
-    }
+    filepath = deBuffer(filepath);
     const resolved = path.resolve(filepath);
     const parts = getPathParts(resolved);
-    let item = _system.getRoot();
+    let item = this._system.getRoot();
     let itemPath = '/';
     let name, i, ii;
     for (i = 0, ii = parts.length; i < ii; ++i) {
       name = parts[i];
       while (item instanceof SymbolicLink) {
         itemPath = path.resolve(path.dirname(itemPath), item.getPath());
-        item = _system.getItem(itemPath);
+        item = this._system.getItem(itemPath);
       }
       if (!item) {
         throw new FSError('ENOENT', filepath);
@@ -349,7 +253,7 @@ Binding.prototype.realpath = function(filepath, encoding, callback, ctx) {
     if (item) {
       while (item instanceof SymbolicLink) {
         itemPath = path.resolve(path.dirname(itemPath), item.getPath());
-        item = _system.getItem(itemPath);
+        item = this._system.getItem(itemPath);
       }
       realPath = itemPath;
     } else {
@@ -362,133 +266,63 @@ Binding.prototype.realpath = function(filepath, encoding, callback, ctx) {
     }
 
     if (encoding === 'buffer') {
-      realPath = bufferFrom(realPath);
+      realPath = Buffer.from(realPath);
     }
 
     return realPath;
   });
 };
 
-/**
- * Fill a Float64Array with stat information
- * This is based on the internal FillStatsArray function in Node.
- * https://github.com/nodejs/node/blob/4e05952a8a75af6df625415db612d3a9a1322682/src/node_file.cc#L533
- * @param {Object} stats An object with file stats
- * @param {Float64Array} statValues A Float64Array where stat values should be inserted
- * @returns {void}
- */
-function fillStatsArray(stats, statValues) {
-  statValues[0] = stats.dev;
-  statValues[1] = stats.mode;
-  statValues[2] = stats.nlink;
-  statValues[3] = stats.uid;
-  statValues[4] = stats.gid;
-  statValues[5] = stats.rdev;
-  statValues[6] = stats.blksize;
-  statValues[7] = stats.ino;
-  statValues[8] = stats.size;
-  statValues[9] = stats.blocks;
-
-  if (statContainsNs) {
-    // nodejs v12.10.0+
-    // This is based on the internal FillStatsArray function in Node.
-    // https://github.com/nodejs/node/blob/3a2e75d9a5c31d20e429d505b82dd182e33f459a/src/node_file.h#L153-L187
-    statValues[10] = Math.floor(stats.atimeMs / 1000);
-    statValues[11] = (stats.atimeMs % 1000) * 1000000;
-    statValues[12] = Math.floor(stats.mtimeMs / 1000);
-    statValues[13] = (stats.mtimeMs % 1000) * 1000000;
-    statValues[14] = Math.floor(stats.ctimeMs / 1000);
-    statValues[15] = (stats.ctimeMs % 1000) * 1000000;
-    statValues[16] = Math.floor(stats.birthtimeMs / 1000);
-    statValues[17] = (stats.birthtimeMs % 1000) * 1000000;
-  } else {
-    // nodejs before v12.10.0
-    // This is based on the internal FillStatsArray function in Node.
-    // https://github.com/nodejs/node/blob/4e05952a8a75af6df625415db612d3a9a1322682/src/node_file.cc#L533
-    statValues[10] = stats.atimeMs;
-    statValues[11] = stats.mtimeMs;
-    statValues[12] = stats.ctimeMs;
-    statValues[13] = stats.birthtimeMs;
+function fillStats(stats) {
+  const target = stats instanceof Float64Array ? statValues : bigintStatValues;
+  for (let i = 0; i < 36; i++) {
+    target[i] = stats[i];
   }
 }
 
 /**
  * Stat an item.
  * @param {string} filepath Path.
- * @param {function(Error, Stats)|Float64Array|BigUint64Array} callback Callback (optional). In Node 7.7.0+ this will be a Float64Array
- * that should be filled with stat values.
+ * @param {function(Error, Float64Array|BigUint64Array)} callback Callback (optional).
  * @param {Object} ctx Context object (optional), only for nodejs v10+.
- * @return {Stats|undefined} Stats or undefined (if sync).
+ * @return {Float64Array|BigUint64Array|undefined} Stats or undefined (if sync).
  */
-Binding.prototype.stat = function(filepath, options, callback, ctx) {
-  // this seems wound not happen in nodejs v10+
-  if (arguments.length < 3) {
-    callback = options;
-    options = {};
-  }
-
+Binding.prototype.stat = function(filepath, bigint, callback, ctx) {
   markSyscall(ctx, 'stat');
 
-  return maybeCallback(wrapStatsCallback(callback), ctx, this, function() {
-    let item = _system.getItem(filepath);
+  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+    filepath = deBuffer(filepath);
+    let item = this._system.getItem(filepath);
     if (item instanceof SymbolicLink) {
-      item = _system.getItem(
+      item = this._system.getItem(
         path.resolve(path.dirname(filepath), item.getPath())
       );
     }
     if (!item) {
       throw new FSError('ENOENT', filepath);
     }
-    const stats = item.getStats();
-
-    // In Node 7.7.0+, binding.stat accepts a Float64Array as the second argument,
-    // which should be filled with stat values.
-    // In prior versions of Node, binding.stat simply returns a Stats instance.
-    if (
-      callback instanceof Float64Array ||
-      callback instanceof BigUint64Array
-    ) {
-      fillStatsArray(stats, callback);
-    } else {
-      fillStatsArray(stats, statValues);
-      return new Stats(stats);
-    }
+    const stats = item.getStats(bigint);
+    fillStats(stats);
+    return stats;
   });
 };
 
 /**
  * Stat an item.
  * @param {number} fd File descriptor.
- * @param {function(Error, Stats)|Float64Array|BigUint64Array} callback Callback (optional). In Node 7.7.0+ this will be a Float64Array
- * that should be filled with stat values.
+ * @param {function(Error, Float64Array|BigUint64Array)} callback Callback (optional).
  * @param {Object} ctx Context object (optional), only for nodejs v10+.
- * @return {Stats|undefined} Stats or undefined (if sync).
+ * @return {Float64Array|BigUint64Array|undefined} Stats or undefined (if sync).
  */
-Binding.prototype.fstat = function(fd, options, callback, ctx) {
-  if (arguments.length < 3) {
-    callback = options;
-    options = {};
-  }
-
+Binding.prototype.fstat = function(fd, bigint, callback, ctx) {
   markSyscall(ctx, 'fstat');
 
-  return maybeCallback(wrapStatsCallback(callback), ctx, this, function() {
-    const descriptor = getDescriptorById(fd);
+  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+    const descriptor = this.getDescriptorById(fd);
     const item = descriptor.getItem();
-    const stats = item.getStats();
-
-    // In Node 7.7.0+, binding.stat accepts a Float64Array as the second argument,
-    // which should be filled with stat values.
-    // In prior versions of Node, binding.stat simply returns a Stats instance.
-    if (
-      callback instanceof Float64Array ||
-      callback instanceof BigUint64Array
-    ) {
-      fillStatsArray(stats, callback);
-    } else {
-      fillStatsArray(stats, statValues);
-      return new Stats(stats);
-    }
+    const stats = item.getStats(bigint);
+    fillStats(stats);
+    return stats;
   });
 };
 
@@ -502,7 +336,7 @@ Binding.prototype.close = function(fd, callback, ctx) {
   markSyscall(ctx, 'close');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    untrackDescriptorById(fd);
+    this.untrackDescriptorById(fd);
   });
 };
 
@@ -519,10 +353,11 @@ Binding.prototype.open = function(pathname, flags, mode, callback, ctx) {
   markSyscall(ctx, 'open');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+    pathname = deBuffer(pathname);
     const descriptor = new FileDescriptor(flags);
-    let item = _system.getItem(pathname);
+    let item = this._system.getItem(pathname);
     while (item instanceof SymbolicLink) {
-      item = _system.getItem(
+      item = this._system.getItem(
         path.resolve(path.dirname(pathname), item.getPath())
       );
     }
@@ -530,7 +365,7 @@ Binding.prototype.open = function(pathname, flags, mode, callback, ctx) {
       throw new FSError('EEXIST', pathname);
     }
     if (descriptor.isCreate() && !item) {
-      const parent = _system.getItem(path.dirname(pathname));
+      const parent = this._system.getItem(path.dirname(pathname));
       if (!parent) {
         throw new FSError('ENOENT', pathname);
       }
@@ -570,7 +405,7 @@ Binding.prototype.open = function(pathname, flags, mode, callback, ctx) {
       descriptor.setPosition(item.getContent().length);
     }
     descriptor.setItem(item);
-    return trackDescriptor(descriptor);
+    return this.trackDescriptor(descriptor);
   });
 };
 
@@ -583,6 +418,7 @@ Binding.prototype.open = function(pathname, flags, mode, callback, ctx) {
  */
 Binding.prototype.openFileHandle = function(pathname, flags, mode, callback) {
   const self = this;
+
   return this.open(pathname, flags, mode, kUsePromises).then(function(fd) {
     // nodejs v10+ fs.promises FileHandler constructor only ask these three properties.
     return {
@@ -620,11 +456,14 @@ Binding.prototype.read = function(
   markSyscall(ctx, 'read');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const descriptor = getDescriptorById(fd);
+    const descriptor = this.getDescriptorById(fd);
     if (!descriptor.isRead()) {
       throw new FSError('EBADF');
     }
     const file = descriptor.getItem();
+    if (file instanceof Directory) {
+      throw new FSError('EISDIR');
+    }
     if (!(file instanceof File)) {
       // deleted or not a regular file
       throw new FSError('EBADF');
@@ -654,10 +493,12 @@ Binding.prototype.copyFile = function(src, dest, flags, callback, ctx) {
   markSyscall(ctx, 'copyfile');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+    src = deBuffer(src);
+    dest = deBuffer(dest);
     const srcFd = this.open(src, constants.O_RDONLY);
 
     try {
-      const srcDescriptor = getDescriptorById(srcFd);
+      const srcDescriptor = this.getDescriptorById(srcFd);
       if (!srcDescriptor.isRead()) {
         throw new FSError('EBADF');
       }
@@ -677,7 +518,7 @@ Binding.prototype.copyFile = function(src, dest, flags, callback, ctx) {
       const destFd = this.open(dest, destFlags);
 
       try {
-        this.write(destFd, srcContent, 0, srcContent.length, 0);
+        this.writeBuffer(destFd, srcContent, 0, srcContent.length, 0);
       } finally {
         this.close(destFd);
       }
@@ -708,7 +549,7 @@ Binding.prototype.writeBuffers = function(
   markSyscall(ctx, 'write');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const descriptor = getDescriptorById(fd);
+    const descriptor = this.getDescriptorById(fd);
     if (!descriptor.isWrite()) {
       throw new FSError('EBADF');
     }
@@ -724,7 +565,7 @@ Binding.prototype.writeBuffers = function(
     const newContent = Buffer.concat(buffers);
     const newLength = position + newContent.length;
     if (content.length < newLength) {
-      const tempContent = bufferAlloc(newLength);
+      const tempContent = Buffer.alloc(newLength);
       content.copy(tempContent);
       content = tempContent;
     }
@@ -760,7 +601,7 @@ Binding.prototype.writeBuffer = function(
   markSyscall(ctx, 'write');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const descriptor = getDescriptorById(fd);
+    const descriptor = this.getDescriptorById(fd);
     if (!descriptor.isWrite()) {
       throw new FSError('EBADF');
     }
@@ -775,12 +616,12 @@ Binding.prototype.writeBuffer = function(
     let content = file.getContent();
     const newLength = position + length;
     if (content.length < newLength) {
-      const newContent = bufferAlloc(newLength);
+      const newContent = Buffer.alloc(newLength);
       content.copy(newContent);
       content = newContent;
     }
     const sourceEnd = Math.min(offset + length, buffer.length);
-    const written = bufferFrom(buffer).copy(
+    const written = Buffer.from(buffer).copy(
       content,
       position,
       offset,
@@ -792,21 +633,6 @@ Binding.prototype.writeBuffer = function(
   });
 };
 
-/**
- * Alias for writeBuffer (used in Node <= 0.10).
- * @param {string} fd File descriptor.
- * @param {Buffer} buffer Buffer with contents to write.
- * @param {number} offset Offset in the buffer to start writing from.
- * @param {number} length Number of bytes to write.
- * @param {?number} position Where to begin writing in the file.  If null,
- *     data will be written to the current file position.
- * @param {function(Error, number, Buffer)} callback Callback (optional) called
- *     with any error, number of bytes written, and the buffer.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
- * @return {number} Number of bytes written (if sync).
- */
-Binding.prototype.write = Binding.prototype.writeBuffer;
-
 /**
  * Write to a file descriptor given a string.
  * @param {string} fd File descriptor.
@@ -828,7 +654,7 @@ Binding.prototype.writeString = function(
 ) {
   markSyscall(ctx, 'write');
 
-  const buffer = bufferFrom(string, encoding);
+  const buffer = Buffer.from(string, encoding);
   let wrapper;
   if (callback && callback !== kUsePromises) {
     if (callback.oncomplete) {
@@ -853,14 +679,16 @@ Binding.prototype.rename = function(oldPath, newPath, callback, ctx) {
   markSyscall(ctx, 'rename');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const oldItem = _system.getItem(oldPath);
+    oldPath = deBuffer(oldPath);
+    newPath = deBuffer(newPath);
+    const oldItem = this._system.getItem(oldPath);
     if (!oldItem) {
       throw new FSError('ENOENT', oldPath);
     }
-    const oldParent = _system.getItem(path.dirname(oldPath));
+    const oldParent = this._system.getItem(path.dirname(oldPath));
     const oldName = path.basename(oldPath);
-    const newItem = _system.getItem(newPath);
-    const newParent = _system.getItem(path.dirname(newPath));
+    const newItem = this._system.getItem(newPath);
+    const newParent = this._system.getItem(path.dirname(newPath));
     const newName = path.basename(newPath);
     if (newItem) {
       // make sure they are the same type
@@ -907,25 +735,15 @@ Binding.prototype.readdir = function(
   callback,
   ctx
 ) {
-  // again, the shorter arguments would not happen in nodejs v10+
-  if (arguments.length === 2) {
-    callback = encoding;
-    encoding = 'utf-8';
-  } else if (arguments.length === 3) {
-    callback = withFileTypes;
-  }
-  if (withFileTypes === true) {
-    notImplemented();
-  }
-
   markSyscall(ctx, 'scandir');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+    dirpath = deBuffer(dirpath);
     let dpath = dirpath;
-    let dir = _system.getItem(dirpath);
+    let dir = this._system.getItem(dirpath);
     while (dir instanceof SymbolicLink) {
       dpath = path.resolve(path.dirname(dpath), dir.getPath());
-      dir = _system.getItem(dpath);
+      dir = this._system.getItem(dpath);
     }
     if (!dir) {
       throw new FSError('ENOENT', dirpath);
@@ -933,12 +751,26 @@ Binding.prototype.readdir = function(
     if (!(dir instanceof Directory)) {
       throw new FSError('ENOTDIR', dirpath);
     }
+    if (!dir.canRead()) {
+      throw new FSError('EACCES', dirpath);
+    }
+
     let list = dir.list();
     if (encoding === 'buffer') {
       list = list.map(function(item) {
-        return bufferFrom(item);
+        return Buffer.from(item);
       });
     }
+
+    if (withFileTypes === true) {
+      const types = list.map(function(name) {
+        const stats = dir.getItem(name).getStats();
+
+        return getDirentType(stats.mode);
+      });
+      list = [list, types];
+    }
+
     return list;
   });
 };
@@ -952,17 +784,11 @@ Binding.prototype.readdir = function(
  * @param {Object} ctx Context object (optional), only for nodejs v10+.
  */
 Binding.prototype.mkdir = function(pathname, mode, recursive, callback, ctx) {
-  if (typeof recursive !== 'boolean') {
-    // when running nodejs < 10
-    ctx = callback;
-    callback = recursive;
-    recursive = false;
-  }
-
   markSyscall(ctx, 'mkdir');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const item = _system.getItem(pathname);
+    pathname = deBuffer(pathname);
+    const item = this._system.getItem(pathname);
     if (item) {
       if (recursive && item instanceof Directory) {
         // silently pass existing folder in recursive mode
@@ -973,7 +799,7 @@ Binding.prototype.mkdir = function(pathname, mode, recursive, callback, ctx) {
 
     const _mkdir = function(_pathname) {
       const parentDir = path.dirname(_pathname);
-      let parent = _system.getItem(parentDir);
+      let parent = this._system.getItem(parentDir);
       if (!parent) {
         if (!recursive) {
           throw new FSError('ENOENT', _pathname);
@@ -1002,7 +828,8 @@ Binding.prototype.rmdir = function(pathname, callback, ctx) {
   markSyscall(ctx, 'rmdir');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const item = _system.getItem(pathname);
+    pathname = deBuffer(pathname);
+    const item = this._system.getItem(pathname);
     if (!item) {
       throw new FSError('ENOENT', pathname);
     }
@@ -1013,7 +840,7 @@ Binding.prototype.rmdir = function(pathname, callback, ctx) {
       throw new FSError('ENOTEMPTY', pathname);
     }
     this.access(path.dirname(pathname), parseInt('0002', 8));
-    const parent = _system.getItem(path.dirname(pathname));
+    const parent = this._system.getItem(path.dirname(pathname));
     parent.removeItem(path.basename(pathname));
   });
 };
@@ -1042,7 +869,7 @@ Binding.prototype.mkdtemp = function(prefix, encoding, callback, ctx) {
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
     prefix = prefix.replace(/X{0,6}$/, 'XXXXXX');
     const parentPath = path.dirname(prefix);
-    const parent = _system.getItem(parentPath);
+    const parent = this._system.getItem(parentPath);
     if (!parent) {
       throw new FSError('ENOENT', prefix);
     }
@@ -1077,7 +904,7 @@ Binding.prototype.mkdtemp = function(prefix, encoding, callback, ctx) {
     parent.addItem(name, dir);
     let uniquePath = path.join(parentPath, name);
     if (encoding === 'buffer') {
-      uniquePath = bufferFrom(uniquePath);
+      uniquePath = Buffer.from(uniquePath);
     }
     return uniquePath;
   });
@@ -1094,7 +921,7 @@ Binding.prototype.ftruncate = function(fd, len, callback, ctx) {
   markSyscall(ctx, 'ftruncate');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const descriptor = getDescriptorById(fd);
+    const descriptor = this.getDescriptorById(fd);
     if (!descriptor.isWrite()) {
       throw new FSError('EINVAL');
     }
@@ -1103,7 +930,7 @@ Binding.prototype.ftruncate = function(fd, len, callback, ctx) {
       throw new FSError('EINVAL');
     }
     const content = file.getContent();
-    const newContent = bufferAlloc(len);
+    const newContent = Buffer.alloc(len);
     content.copy(newContent);
     file.setContent(newContent);
   });
@@ -1130,7 +957,8 @@ Binding.prototype.chown = function(pathname, uid, gid, callback, ctx) {
   markSyscall(ctx, 'chown');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const item = _system.getItem(pathname);
+    pathname = deBuffer(pathname);
+    const item = this._system.getItem(pathname);
     if (!item) {
       throw new FSError('ENOENT', pathname);
     }
@@ -1151,7 +979,7 @@ Binding.prototype.fchown = function(fd, uid, gid, callback, ctx) {
   markSyscall(ctx, 'fchown');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const descriptor = getDescriptorById(fd);
+    const descriptor = this.getDescriptorById(fd);
     const item = descriptor.getItem();
     item.setUid(uid);
     item.setGid(gid);
@@ -1169,7 +997,8 @@ Binding.prototype.chmod = function(pathname, mode, callback, ctx) {
   markSyscall(ctx, 'chmod');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const item = _system.getItem(pathname);
+    pathname = deBuffer(pathname);
+    const item = this._system.getItem(pathname);
     if (!item) {
       throw new FSError('ENOENT', pathname);
     }
@@ -1188,7 +1017,7 @@ Binding.prototype.fchmod = function(fd, mode, callback, ctx) {
   markSyscall(ctx, 'fchmod');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const descriptor = getDescriptorById(fd);
+    const descriptor = this.getDescriptorById(fd);
     const item = descriptor.getItem();
     item.setMode(mode);
   });
@@ -1204,14 +1033,15 @@ Binding.prototype.unlink = function(pathname, callback, ctx) {
   markSyscall(ctx, 'unlink');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const item = _system.getItem(pathname);
+    pathname = deBuffer(pathname);
+    const item = this._system.getItem(pathname);
     if (!item) {
       throw new FSError('ENOENT', pathname);
     }
     if (item instanceof Directory) {
       throw new FSError('EPERM', pathname);
     }
-    const parent = _system.getItem(path.dirname(pathname));
+    const parent = this._system.getItem(path.dirname(pathname));
     parent.removeItem(path.basename(pathname));
   });
 };
@@ -1228,7 +1058,8 @@ Binding.prototype.utimes = function(pathname, atime, mtime, callback, ctx) {
   markSyscall(ctx, 'utimes');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const item = _system.getItem(pathname);
+    pathname = deBuffer(pathname);
+    const item = this._system.getItem(pathname);
     if (!item) {
       throw new FSError('ENOENT', pathname);
     }
@@ -1249,7 +1080,7 @@ Binding.prototype.futimes = function(fd, atime, mtime, callback, ctx) {
   markSyscall(ctx, 'futimes');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const descriptor = getDescriptorById(fd);
+    const descriptor = this.getDescriptorById(fd);
     const item = descriptor.getItem();
     item.setATime(new Date(atime * 1000));
     item.setMTime(new Date(mtime * 1000));
@@ -1266,7 +1097,7 @@ Binding.prototype.fsync = function(fd, callback, ctx) {
   markSyscall(ctx, 'fsync');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    getDescriptorById(fd);
+    this.getDescriptorById(fd);
   });
 };
 
@@ -1280,7 +1111,7 @@ Binding.prototype.fdatasync = function(fd, callback, ctx) {
   markSyscall(ctx, 'fdatasync');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    getDescriptorById(fd);
+    this.getDescriptorById(fd);
   });
 };
 
@@ -1295,17 +1126,19 @@ Binding.prototype.link = function(srcPath, destPath, callback, ctx) {
   markSyscall(ctx, 'link');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const item = _system.getItem(srcPath);
+    srcPath = deBuffer(srcPath);
+    destPath = deBuffer(destPath);
+    const item = this._system.getItem(srcPath);
     if (!item) {
       throw new FSError('ENOENT', srcPath);
     }
     if (item instanceof Directory) {
       throw new FSError('EPERM', srcPath);
     }
-    if (_system.getItem(destPath)) {
+    if (this._system.getItem(destPath)) {
       throw new FSError('EEXIST', destPath);
     }
-    const parent = _system.getItem(path.dirname(destPath));
+    const parent = this._system.getItem(path.dirname(destPath));
     if (!parent) {
       throw new FSError('ENOENT', destPath);
     }
@@ -1328,10 +1161,12 @@ Binding.prototype.symlink = function(srcPath, destPath, type, callback, ctx) {
   markSyscall(ctx, 'symlink');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    if (_system.getItem(destPath)) {
+    srcPath = deBuffer(srcPath);
+    destPath = deBuffer(destPath);
+    if (this._system.getItem(destPath)) {
       throw new FSError('EEXIST', destPath);
     }
-    const parent = _system.getItem(path.dirname(destPath));
+    const parent = this._system.getItem(path.dirname(destPath));
     if (!parent) {
       throw new FSError('ENOENT', destPath);
     }
@@ -1362,7 +1197,8 @@ Binding.prototype.readlink = function(pathname, encoding, callback, ctx) {
   markSyscall(ctx, 'readlink');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    const link = _system.getItem(pathname);
+    pathname = deBuffer(pathname);
+    const link = this._system.getItem(pathname);
     if (!link) {
       throw new FSError('ENOENT', pathname);
     }
@@ -1371,7 +1207,7 @@ Binding.prototype.readlink = function(pathname, encoding, callback, ctx) {
     }
     let linkPath = link.getPath();
     if (encoding === 'buffer') {
-      linkPath = bufferFrom(linkPath);
+      linkPath = Buffer.from(linkPath);
     }
     return linkPath;
   });
@@ -1380,39 +1216,22 @@ Binding.prototype.readlink = function(pathname, encoding, callback, ctx) {
 /**
  * Stat an item.
  * @param {string} filepath Path.
- * @param {function(Error, Stats)|Float64Array|BigUint64Array} callback Callback (optional). In Node 7.7.0+ this will be a Float64Array
- * that should be filled with stat values.
+ * @param {function(Error, Float64Array|BigUint64Array)} callback Callback (optional).
  * @param {Object} ctx Context object (optional), only for nodejs v10+.
- * @return {Stats|undefined} Stats or undefined (if sync).
+ * @return {Float64Array|BigUint64Array|undefined} Stats or undefined (if sync).
  */
-Binding.prototype.lstat = function(filepath, options, callback, ctx) {
-  if (arguments.length < 3) {
-    // this would not happend in nodejs v10+
-    callback = options;
-    options = {};
-  }
-
+Binding.prototype.lstat = function(filepath, bigint, callback, ctx) {
   markSyscall(ctx, 'lstat');
 
-  return maybeCallback(wrapStatsCallback(callback), ctx, this, function() {
-    const item = _system.getItem(filepath);
+  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+    filepath = deBuffer(filepath);
+    const item = this._system.getItem(filepath);
     if (!item) {
       throw new FSError('ENOENT', filepath);
     }
-    const stats = item.getStats();
-
-    // In Node 7.7.0+, binding.stat accepts a Float64Array as the second argument,
-    // which should be filled with stat values.
-    // In prior versions of Node, binding.stat simply returns a Stats instance.
-    if (
-      callback instanceof Float64Array ||
-      callback instanceof BigUint64Array
-    ) {
-      fillStatsArray(stats, callback);
-    } else {
-      fillStatsArray(stats, statValues);
-      return new Stats(item.getStats());
-    }
+    const stats = item.getStats(bigint);
+    fillStats(stats);
+    return stats;
   });
 };
 
@@ -1427,14 +1246,15 @@ Binding.prototype.access = function(filepath, mode, callback, ctx) {
   markSyscall(ctx, 'access');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function() {
-    let item = _system.getItem(filepath);
+    filepath = deBuffer(filepath);
+    let item = this._system.getItem(filepath);
     let links = 0;
     while (item instanceof SymbolicLink) {
       if (links > MAX_LINKS) {
         throw new FSError('ELOOP', filepath);
       }
       filepath = path.resolve(path.dirname(filepath), item.getPath());
-      item = _system.getItem(filepath);
+      item = this._system.getItem(filepath);
       ++links;
     }
     if (!item) {
