@@ -19,13 +19,13 @@ const permissions = {
 };
 
 function getUid() {
-  // force NaN on windows.
-  return process.getuid ? process.getuid() : NaN;
+  // force 0 on windows.
+  return process.getuid ? process.getuid() : 0;
 }
 
 function getGid() {
-  // force NaN on windows.
-  return process.getgid ? process.getgid() : NaN;
+  // force 0 on windows.
+  return process.getgid ? process.getgid() : 0;
 }
 
 /**
@@ -92,14 +92,13 @@ function Item() {
  * Add execute if read allowed
  * See notes in index.js -> mapping#addDir
  */
-// prettier-ignore
 Item.fixWin32Permissions = mode =>
-  (process.platform !== 'win32')
-  ? mode
-  : mode |
-      ((mode & permissions.USER_READ) && permissions.USER_EXEC) |
-      ((mode & permissions.GROUP_READ) && permissions.GROUP_EXEC) |
-      ((mode & permissions.OTHER_READ) && permissions.OTHER_EXEC);
+  process.platform !== 'win32'
+    ? mode
+    : mode |
+      (mode & permissions.USER_READ && permissions.USER_EXEC) |
+      (mode & permissions.GROUP_READ && permissions.GROUP_EXEC) |
+      (mode & permissions.OTHER_READ && permissions.OTHER_EXEC);
 
 /**
  * Determine if the current user has read permission.
@@ -109,10 +108,9 @@ Item.prototype.canRead = function() {
   const uid = getUid();
   const gid = getGid();
   let can = false;
-  if (uid === 0) {
+  if (process.getuid && uid === 0) {
     can = true;
-  } else if (uid === this._uid || uid !== uid) {
-    // (uid !== uid) means uid is NaN, only for windows
+  } else if (uid === this._uid) {
     can = (permissions.USER_READ & this._mode) === permissions.USER_READ;
   } else if (gid === this._gid) {
     can = (permissions.GROUP_READ & this._mode) === permissions.GROUP_READ;
@@ -130,10 +128,9 @@ Item.prototype.canWrite = function() {
   const uid = getUid();
   const gid = getGid();
   let can = false;
-  if (uid === 0) {
+  if (process.getuid && uid === 0) {
     can = true;
-  } else if (uid === this._uid || uid !== uid) {
-    // (uid !== uid) means uid is NaN, only for windows
+  } else if (uid === this._uid) {
     can = (permissions.USER_WRITE & this._mode) === permissions.USER_WRITE;
   } else if (gid === this._gid) {
     can = (permissions.GROUP_WRITE & this._mode) === permissions.GROUP_WRITE;
@@ -151,10 +148,9 @@ Item.prototype.canExecute = function() {
   const uid = getUid();
   const gid = getGid();
   let can = false;
-  if (uid === 0) {
+  if (process.getuid && uid === 0) {
     can = true;
-  } else if (uid === this._uid || isNaN(uid)) {
-    // NaN occurs on windows
+  } else if (uid === this._uid) {
     can = (permissions.USER_EXEC & this._mode) === permissions.USER_EXEC;
   } else if (gid === this._gid) {
     can = (permissions.GROUP_EXEC & this._mode) === permissions.GROUP_EXEC;
@@ -283,24 +279,33 @@ Item.prototype.setGid = function(gid) {
  * Get item stats.
  * @return {Object} Stats properties.
  */
-Item.prototype.getStats = function() {
-  return {
-    dev: 8675309,
-    nlink: this.links,
-    uid: this.getUid(),
-    gid: this.getGid(),
-    rdev: 0,
-    blksize: 4096,
-    ino: this._id,
-    atime: this.getATime(),
-    mtime: this.getMTime(),
-    ctime: this.getCTime(),
-    birthtime: this.getBirthtime(),
-    atimeMs: +this.getATime(),
-    mtimeMs: +this.getMTime(),
-    ctimeMs: +this.getCTime(),
-    birthtimeMs: +this.getBirthtime()
-  };
+Item.prototype.getStats = function(bigint) {
+  const stats = bigint ? new BigUint64Array(36) : new Float64Array(36);
+  const convert = bigint ? v => BigInt(v) : v => v;
+
+  stats[0] = convert(8675309); // dev
+  // [1] is mode
+  stats[2] = convert(this.links); // nlink
+  stats[3] = convert(this.getUid()); // uid
+  stats[4] = convert(this.getGid()); // gid
+  stats[5] = convert(0); // rdev
+  stats[6] = convert(4096); // blksize
+  stats[7] = convert(this._id); // ino
+  // [8] is size
+  // [9] is blocks
+  const atimeMs = +this.getATime();
+  stats[10] = convert(Math.floor(atimeMs / 1000)); // atime seconds
+  stats[11] = convert((atimeMs % 1000) * 1000000); // atime nanoseconds
+  const mtimeMs = +this.getMTime();
+  stats[12] = convert(Math.floor(mtimeMs / 1000)); // atime seconds
+  stats[13] = convert((mtimeMs % 1000) * 1000000); // atime nanoseconds
+  const ctimeMs = +this.getCTime();
+  stats[14] = convert(Math.floor(ctimeMs / 1000)); // atime seconds
+  stats[15] = convert((ctimeMs % 1000) * 1000000); // atime nanoseconds
+  const birthtimeMs = +this.getBirthtime();
+  stats[16] = convert(Math.floor(birthtimeMs / 1000)); // atime seconds
+  stats[17] = convert((birthtimeMs % 1000) * 1000000); // atime nanoseconds
+  return stats;
 };
 
 /**
