@@ -3,8 +3,6 @@
 const chai = require('chai');
 const constants = require('constants');
 const semver = require('semver');
-const fs = require('fs');
-const hasPromise = !!fs.promises;
 
 /** @type {boolean} */
 chai.config.includeStack = true;
@@ -45,8 +43,6 @@ exports.inVersion = function(range) {
   }
 };
 
-exports.withPromise = hasPromise ? TEST : NO_TEST;
-
 /**
  * Convert a string to flags for fs.open.
  * @param {string} str String.
