@@ -4,10 +4,8 @@ const helper = require('../helper');
 const fs = require('fs');
 const mock = require('../../lib/index');
 const assert = helper.assert;
-const withPromise = helper.withPromise;
 
-if (fs.access && fs.accessSync && process.getuid && process.getgid) {
-  // TODO: drop condition when dropping Node < 0.12 support
+if (process.getuid && process.getgid) {
   // TODO: figure out how fs.access() works on Windows (without gid/uid)
 
   describe('fs.access(path[, mode], callback)', function() {
@@ -67,7 +65,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access(Buffer.from('path/to/accessible/file'), done);
     });
 
-    withPromise.it('promise works for an accessible file', function(done) {
+    it('promise works for an accessible file', function(done) {
       fs.promises.access('path/to/accessible/file').then(done, done);
     });
 
@@ -75,7 +73,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/000', done);
     });
 
-    withPromise.it('promise works 000 (and no mode arg)', function(done) {
+    it('promise works 000 (and no mode arg)', function(done) {
       fs.promises.access('path/to/000').then(done, done);
     });
 
@@ -83,7 +81,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/000', fs.F_OK, done);
     });
 
-    withPromise.it('promise works F_OK and 000', function(done) {
+    it('promise works F_OK and 000', function(done) {
       fs.promises.access('path/to/000', fs.F_OK).then(done, done);
     });
 
@@ -95,11 +93,10 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       });
     });
 
-    withPromise.it('promise generates EACCES for R_OK and 000', function(done) {
+    it('promise generates EACCES for R_OK and 000', function(done) {
       fs.promises.access('path/to/000', fs.R_OK).then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -117,11 +114,10 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       });
     });
 
-    withPromise.it('promise generates EACCES for W_OK and 000', function(done) {
+    it('promise generates EACCES for W_OK and 000', function(done) {
       fs.promises.access('path/to/000', fs.W_OK).then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -139,11 +135,10 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       });
     });
 
-    withPromise.it('promise generates EACCES for X_OK and 000', function(done) {
+    it('promise generates EACCES for X_OK and 000', function(done) {
       fs.promises.access('path/to/000', fs.X_OK).then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -157,7 +152,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/111', done);
     });
 
-    withPromise.it('promise works 111 (and no mode arg)', function(done) {
+    it('promise works 111 (and no mode arg)', function(done) {
       fs.promises.access('path/to/111').then(done, done);
     });
 
@@ -165,7 +160,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/111', fs.F_OK, done);
     });
 
-    withPromise.it('promise works F_OK and 111', function(done) {
+    it('promise works F_OK and 111', function(done) {
       fs.promises.access('path/to/111', fs.F_OK).then(done, done);
     });
 
@@ -173,7 +168,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/111', fs.X_OK, done);
     });
 
-    withPromise.it('promise works X_OK and 111', function(done) {
+    it('promise works X_OK and 111', function(done) {
       fs.promises.access('path/to/111', fs.X_OK).then(done, done);
     });
 
@@ -185,11 +180,10 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       });
     });
 
-    withPromise.it('promise generates EACCES for R_OK and 111', function(done) {
+    it('promise generates EACCES for R_OK and 111', function(done) {
       fs.promises.access('path/to/111', fs.R_OK).then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -207,11 +201,10 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       });
     });
 
-    withPromise.it('promise generates EACCES for W_OK and 111', function(done) {
+    it('promise generates EACCES for W_OK and 111', function(done) {
       fs.promises.access('path/to/111', fs.W_OK).then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -225,7 +218,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/write/only', done);
     });
 
-    withPromise.it('promise works for 222 (and no mode arg)', function(done) {
+    it('promise works for 222 (and no mode arg)', function(done) {
       fs.promises.access('path/to/write/only').then(done, done);
     });
 
@@ -233,7 +226,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/write/only', fs.F_OK, done);
     });
 
-    withPromise.it('promise works F_OK and 222', function(done) {
+    it('promise works F_OK and 222', function(done) {
       fs.promises.access('path/to/write/only', fs.F_OK).then(done, done);
     });
 
@@ -241,7 +234,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/write/only', fs.W_OK, done);
     });
 
-    withPromise.it('promise works W_OK and 222', function(done) {
+    it('promise works W_OK and 222', function(done) {
       fs.promises.access('path/to/write/only', fs.W_OK).then(done, done);
     });
 
@@ -253,11 +246,10 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       });
     });
 
-    withPromise.it('promise generates EACCES for R_OK and 222', function(done) {
+    it('promise generates EACCES for R_OK and 222', function(done) {
       fs.promises.access('path/to/write/only', fs.R_OK).then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -275,11 +267,10 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       });
     });
 
-    withPromise.it('promise generates EACCES for X_OK and 222', function(done) {
+    it('promise generates EACCES for X_OK and 222', function(done) {
       fs.promises.access('path/to/write/only', fs.X_OK).then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -293,7 +284,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/333', done);
     });
 
-    withPromise.it('promise works for 333 (and no mode arg)', function(done) {
+    it('promise works for 333 (and no mode arg)', function(done) {
       fs.promises.access('path/to/333').then(done, done);
     });
 
@@ -301,7 +292,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/333', fs.F_OK, done);
     });
 
-    withPromise.it('promise works F_OK and 333', function(done) {
+    it('promise works F_OK and 333', function(done) {
       fs.promises.access('path/to/333', fs.F_OK).then(done, done);
     });
 
@@ -309,7 +300,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/333', fs.W_OK, done);
     });
 
-    withPromise.it('promise works W_OK and 333', function(done) {
+    it('promise works W_OK and 333', function(done) {
       fs.promises.access('path/to/333', fs.W_OK).then(done, done);
     });
 
@@ -317,7 +308,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/333', fs.X_OK, done);
     });
 
-    withPromise.it('promise works X_OK and 333', function(done) {
+    it('promise works X_OK and 333', function(done) {
       fs.promises.access('path/to/333', fs.X_OK).then(done, done);
     });
 
@@ -325,7 +316,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/333', fs.X_OK | fs.W_OK, done);
     });
 
-    withPromise.it('promise works X_OK | W_OK and 333', function(done) {
+    it('promise works X_OK | W_OK and 333', function(done) {
       fs.promises.access('path/to/333', fs.X_OK | fs.W_OK).then(done, done);
     });
 
@@ -337,11 +328,10 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       });
     });
 
-    withPromise.it('promise generates EACCES for R_OK and 333', function(done) {
+    it('promise generates EACCES for R_OK and 333', function(done) {
       fs.promises.access('path/to/333', fs.R_OK).then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -355,7 +345,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/444', done);
     });
 
-    withPromise.it('promise works for 444 (and no mode arg)', function(done) {
+    it('promise works for 444 (and no mode arg)', function(done) {
       fs.promises.access('path/to/444').then(done, done);
     });
 
@@ -363,7 +353,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/444', fs.F_OK, done);
     });
 
-    withPromise.it('promise works F_OK and 444', function(done) {
+    it('promise works F_OK and 444', function(done) {
       fs.promises.access('path/to/444', fs.F_OK).then(done, done);
     });
 
@@ -371,7 +361,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/444', fs.R_OK, done);
     });
 
-    withPromise.it('promise works R_OK and 444', function(done) {
+    it('promise works R_OK and 444', function(done) {
       fs.promises.access('path/to/444', fs.R_OK).then(done, done);
     });
 
@@ -383,11 +373,10 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       });
     });
 
-    withPromise.it('promise generates EACCES for W_OK and 444', function(done) {
+    it('promise generates EACCES for W_OK and 444', function(done) {
       fs.promises.access('path/to/444', fs.W_OK).then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -405,11 +394,10 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       });
     });
 
-    withPromise.it('promise generates EACCES for X_OK and 444', function(done) {
+    it('promise generates EACCES for X_OK and 444', function(done) {
       fs.promises.access('path/to/444', fs.X_OK).then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -423,7 +411,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/555', done);
     });
 
-    withPromise.it('promise works for 555 (and no mode arg)', function(done) {
+    it('promise works for 555 (and no mode arg)', function(done) {
       fs.promises.access('path/to/555').then(done, done);
     });
 
@@ -431,7 +419,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/555', fs.F_OK, done);
     });
 
-    withPromise.it('promise works F_OK and 555', function(done) {
+    it('promise works F_OK and 555', function(done) {
       fs.promises.access('path/to/555', fs.F_OK).then(done, done);
     });
 
@@ -439,7 +427,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/555', fs.R_OK, done);
     });
 
-    withPromise.it('promise works R_OK and 555', function(done) {
+    it('promise works R_OK and 555', function(done) {
       fs.promises.access('path/to/555', fs.R_OK).then(done, done);
     });
 
@@ -447,7 +435,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/555', fs.X_OK, done);
     });
 
-    withPromise.it('promise works X_OK and 555', function(done) {
+    it('promise works X_OK and 555', function(done) {
       fs.promises.access('path/to/555', fs.X_OK).then(done, done);
     });
 
@@ -455,7 +443,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/555', fs.R_OK | fs.X_OK, done);
     });
 
-    withPromise.it('promise works R_OK | X_OK and 555', function(done) {
+    it('promise works R_OK | X_OK and 555', function(done) {
       fs.promises.access('path/to/555', fs.R_OK | fs.X_OK).then(done, done);
     });
 
@@ -467,11 +455,10 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       });
     });
 
-    withPromise.it('promise generates EACCES for W_OK and 555', function(done) {
+    it('promise generates EACCES for W_OK and 555', function(done) {
       fs.promises.access('path/to/555', fs.W_OK).then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -485,7 +472,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/666', done);
     });
 
-    withPromise.it('promise works for 666 (and no mode arg)', function(done) {
+    it('promise works for 666 (and no mode arg)', function(done) {
       fs.promises.access('path/to/666').then(done, done);
     });
 
@@ -493,7 +480,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/666', fs.F_OK, done);
     });
 
-    withPromise.it('promise works F_OK and 666', function(done) {
+    it('promise works F_OK and 666', function(done) {
       fs.promises.access('path/to/666', fs.F_OK).then(done, done);
     });
 
@@ -501,7 +488,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/666', fs.R_OK, done);
     });
 
-    withPromise.it('promise works R_OK and 666', function(done) {
+    it('promise works R_OK and 666', function(done) {
       fs.promises.access('path/to/666', fs.R_OK).then(done, done);
     });
 
@@ -509,7 +496,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/666', fs.W_OK, done);
     });
 
-    withPromise.it('promise works W_OK and 666', function(done) {
+    it('promise works W_OK and 666', function(done) {
       fs.promises.access('path/to/666', fs.W_OK).then(done, done);
     });
 
@@ -517,7 +504,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/666', fs.R_OK | fs.W_OK, done);
     });
 
-    withPromise.it('promise works R_OK | W_OK and 666', function(done) {
+    it('promise works R_OK | W_OK and 666', function(done) {
       fs.promises.access('path/to/666', fs.R_OK | fs.W_OK).then(done, done);
     });
 
@@ -529,11 +516,10 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       });
     });
 
-    withPromise.it('promise generates EACCES for X_OK and 666', function(done) {
+    it('promise generates EACCES for X_OK and 666', function(done) {
       fs.promises.access('path/to/666', fs.X_OK).then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -547,7 +533,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/777', done);
     });
 
-    withPromise.it('promise works for 777 (and no mode arg)', function(done) {
+    it('promise works for 777 (and no mode arg)', function(done) {
       fs.promises.access('path/to/777').then(done, done);
     });
 
@@ -555,7 +541,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/777', fs.F_OK, done);
     });
 
-    withPromise.it('promise works F_OK and 777', function(done) {
+    it('promise works F_OK and 777', function(done) {
       fs.promises.access('path/to/777', fs.F_OK).then(done, done);
     });
 
@@ -563,7 +549,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/777', fs.R_OK, done);
     });
 
-    withPromise.it('promise works R_OK and 777', function(done) {
+    it('promise works R_OK and 777', function(done) {
       fs.promises.access('path/to/777', fs.R_OK).then(done, done);
     });
 
@@ -571,7 +557,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/777', fs.W_OK, done);
     });
 
-    withPromise.it('promise works W_OK and 777', function(done) {
+    it('promise works W_OK and 777', function(done) {
       fs.promises.access('path/to/777', fs.W_OK).then(done, done);
     });
 
@@ -579,7 +565,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/777', fs.X_OK, done);
     });
 
-    withPromise.it('promise works X_OK and 777', function(done) {
+    it('promise works X_OK and 777', function(done) {
       fs.promises.access('path/to/777', fs.X_OK).then(done, done);
     });
 
@@ -587,7 +573,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/777', fs.X_OK | fs.W_OK, done);
     });
 
-    withPromise.it('promise works X_OK | W_OK and 777', function(done) {
+    it('promise works X_OK | W_OK and 777', function(done) {
       fs.promises.access('path/to/777', fs.X_OK | fs.W_OK).then(done, done);
     });
 
@@ -595,7 +581,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/777', fs.X_OK | fs.R_OK, done);
     });
 
-    withPromise.it('promise works X_OK | R_OK and 777', function(done) {
+    it('promise works X_OK | R_OK and 777', function(done) {
       fs.promises.access('path/to/777', fs.X_OK | fs.R_OK).then(done, done);
     });
 
@@ -603,7 +589,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/777', fs.R_OK | fs.W_OK, done);
     });
 
-    withPromise.it('promise works R_OK | W_OK and 777', function(done) {
+    it('promise works R_OK | W_OK and 777', function(done) {
       fs.promises.access('path/to/777', fs.R_OK | fs.W_OK).then(done, done);
     });
 
@@ -611,7 +597,7 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       fs.access('path/to/777', fs.R_OK | fs.W_OK | fs.X_OK, done);
     });
 
-    withPromise.it('promise works R_OK | W_OK | X_OK and 777', function(done) {
+    it('promise works R_OK | W_OK | X_OK and 777', function(done) {
       fs.promises
         .access('path/to/777', fs.R_OK | fs.W_OK | fs.X_OK)
         .then(done, done);
@@ -625,22 +611,18 @@ if (fs.access && fs.accessSync && process.getuid && process.getgid) {
       });
     });
 
-    withPromise.it(
-      'promise generates EACCESS for F_OK and an unreadable parent',
-      function(done) {
-        fs.promises.access('unreadable/readable-child').then(
-          function() {
-            assert.fail('should not succeed.');
-            done();
-          },
-          function(err) {
-            assert.instanceOf(err, Error);
-            assert.equal(err.code, 'EACCES');
-            done();
-          }
-        );
-      }
-    );
+    it('promise generates EACCESS for F_OK and an unreadable parent', function(done) {
+      fs.promises.access('unreadable/readable-child').then(
+        function() {
+          done(new Error('should not succeed.'));
+        },
+        function(err) {
+          assert.instanceOf(err, Error);
+          assert.equal(err.code, 'EACCES');
+          done();
+        }
+      );
+    });
   });
 
   describe('fs.accessSync(path[, mode])', function() {
