@@ -5,7 +5,6 @@ const fs = require('fs');
 const mock = require('../../lib/index');
 
 const assert = helper.assert;
-const withPromise = helper.withPromise;
 
 describe('fs.chmod(path, mode, callback)', function() {
   beforeEach(function() {
@@ -37,7 +36,7 @@ describe('fs.chmod(path, mode, callback)', function() {
     });
   });
 
-  withPromise.it('promise changes permissions of a file', function(done) {
+  it('promise changes permissions of a file', function(done) {
     fs.promises.chmod('file.txt', parseInt('0664', 8)).then(function() {
       const stats = fs.statSync('file.txt');
       assert.equal(stats.mode & parseInt('0777', 8), parseInt('0664', 8));
@@ -53,11 +52,10 @@ describe('fs.chmod(path, mode, callback)', function() {
     });
   });
 
-  withPromise.it('promise fails if file does not exist', function(done) {
+  it('promise fails if file does not exist', function(done) {
     fs.promises.chmod('bogus.txt', parseInt('0664', 8)).then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -109,7 +107,7 @@ describe('fs.fchmod(fd, mode, callback)', function() {
     });
   });
 
-  withPromise.it('promise changes permissions of a file', function(done) {
+  it('promise changes permissions of a file', function(done) {
     fs.promises
       .open('file.txt', 'r')
       .then(function(fd) {
