@@ -5,7 +5,6 @@ const fs = require('fs');
 const mock = require('../../lib/index');
 
 const assert = helper.assert;
-const withPromise = helper.withPromise;
 
 describe('fs.chown(path, uid, gid, callback)', function() {
   beforeEach(function() {
@@ -24,7 +23,7 @@ describe('fs.chown(path, uid, gid, callback)', function() {
     fs.chown(Buffer.from('file.txt'), 42, 43, done);
   });
 
-  withPromise.it('promise changes ownership of a file', function(done) {
+  it('promise changes ownership of a file', function(done) {
     fs.promises.chown('file.txt', 42, 43).then(done, done);
   });
 
@@ -35,11 +34,10 @@ describe('fs.chown(path, uid, gid, callback)', function() {
     });
   });
 
-  withPromise.it('promise fails if file does not exist', function(done) {
+  it('promise fails if file does not exist', function(done) {
     fs.promises.chown('bogus.txt', 42, 43).then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -84,7 +82,7 @@ describe('fs.fchown(fd, uid, gid, callback)', function() {
     fs.fchown(fd, 42, 43, done);
   });
 
-  withPromise.it('promise changes ownership of a file', function(done) {
+  it('promise changes ownership of a file', function(done) {
     fs.promises
       .open('file.txt', 'r')
       .then(function(fd) {
