@@ -5,7 +5,6 @@ const fs = require('fs');
 const mock = require('../../lib/index');
 
 const assert = helper.assert;
-const withPromise = helper.withPromise;
 
 if (fs.copyFile && fs.copyFileSync) {
   describe('fs.copyFile(src, dest[, flags], callback)', function() {
@@ -43,9 +42,7 @@ if (fs.copyFile && fs.copyFileSync) {
       );
     });
 
-    withPromise.it('promise copies a file to an empty directory', function(
-      done
-    ) {
+    it('promise copies a file to an empty directory', function(done) {
       fs.promises
         .copyFile('path/to/src.txt', 'empty/dest.txt')
         .then(function() {
@@ -69,7 +66,7 @@ if (fs.copyFile && fs.copyFileSync) {
       });
     });
 
-    withPromise.it('promise truncates dest file if it exists', function(done) {
+    it('promise truncates dest file if it exists', function(done) {
       fs.promises
         .copyFile('path/to/src.txt', 'path/to/other.txt')
         .then(function() {
@@ -94,9 +91,7 @@ if (fs.copyFile && fs.copyFileSync) {
       );
     });
 
-    withPromise.it('promise throws if dest exists and exclusive', function(
-      done
-    ) {
+    it('promise throws if dest exists and exclusive', function(done) {
       fs.promises
         .copyFile(
           'path/to/src.txt',
@@ -105,8 +100,7 @@ if (fs.copyFile && fs.copyFileSync) {
         )
         .then(
           function() {
-            assert.fail('should not succeed.');
-            done();
+            done(new Error('should not succeed.'));
           },
           function(err) {
             assert.instanceOf(err, Error);
@@ -124,11 +118,10 @@ if (fs.copyFile && fs.copyFileSync) {
       });
     });
 
-    withPromise.it('promise fails if src does not exist', function(done) {
+    it('promise fails if src does not exist', function(done) {
       fs.promises.copyFile('path/to/bogus.txt', 'empty/dest.txt').then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -146,11 +139,10 @@ if (fs.copyFile && fs.copyFileSync) {
       });
     });
 
-    withPromise.it('promise fails if dest path does not exist', function(done) {
+    it('promise fails if dest path does not exist', function(done) {
       fs.promises.copyFile('path/to/src.txt', 'path/nope/dest.txt').then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -168,11 +160,10 @@ if (fs.copyFile && fs.copyFileSync) {
       });
     });
 
-    withPromise.it('promise fails if dest is a directory', function(done) {
+    it('promise fails if dest is a directory', function(done) {
       fs.promises.copyFile('path/to/src.txt', 'empty').then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
