@@ -5,9 +5,8 @@ const fs = require('fs');
 const mock = require('../../lib/index');
 
 const assert = helper.assert;
-const withPromise = helper.withPromise;
 
-describe('fs.lstat(path, callback)', function() {
+describe('fs.lstat(path, options, callback)', function() {
   beforeEach(function() {
     mock({
       'file.txt': mock.file({
@@ -34,6 +33,18 @@ describe('fs.lstat(path, callback)', function() {
     });
   });
 
+  it('stats a symbolic link with bigint', function(done) {
+    fs.lstat('link', {bigint: true}, function(err, stats) {
+      if (err) {
+        return done(err);
+      }
+      assert.isTrue(stats.isSymbolicLink());
+      assert.isFalse(stats.isFile());
+      assert.equal(typeof stats.mtimeMs, 'bigint');
+      done();
+    });
+  });
+
   it('suports Buffer input', function(done) {
     fs.lstat(Buffer.from('link'), function(err, stats) {
       if (err) {
@@ -46,7 +57,19 @@ describe('fs.lstat(path, callback)', function() {
     });
   });
 
-  withPromise.it('promise stats a symbolic link', function(done) {
+  it('suports Buffer input with bigint', function(done) {
+    fs.lstat(Buffer.from('link'), {bigint: true}, function(err, stats) {
+      if (err) {
+        return done(err);
+      }
+      assert.isTrue(stats.isSymbolicLink());
+      assert.isFalse(stats.isFile());
+      assert.equal(typeof stats.mtimeMs, 'bigint');
+      done();
+    });
+  });
+
+  it('promise stats a symbolic link', function(done) {
     fs.promises.lstat('link').then(function(stats) {
       assert.isTrue(stats.isSymbolicLink());
       assert.isFalse(stats.isFile());
@@ -55,6 +78,15 @@ describe('fs.lstat(path, callback)', function() {
     }, done);
   });
 
+  it('promise stats a symbolic link with bigint', function(done) {
+    fs.promises.lstat('link', {bigint: true}).then(function(stats) {
+      assert.isTrue(stats.isSymbolicLink());
+      assert.isFalse(stats.isFile());
+      assert.equal(typeof stats.mtimeMs, 'bigint');
+      done();
+    }, done);
+  });
+
   it('stats a regular file', function(done) {
     fs.lstat('file.txt', function(err, stats) {
       if (err) {
@@ -67,7 +99,19 @@ describe('fs.lstat(path, callback)', function() {
     });
   });
 
-  withPromise.it('promise stats a regular file', function(done) {
+  it('stats a regular file with bigint', function(done) {
+    fs.lstat('file.txt', {bigint: true}, function(err, stats) {
+      if (err) {
+        return done(err);
+      }
+      assert.isTrue(stats.isFile());
+      assert.isFalse(stats.isSymbolicLink());
+      assert.equal(typeof stats.mtimeMs, 'bigint');
+      done();
+    });
+  });
+
+  it('promise stats a regular file', function(done) {
     fs.promises.lstat('file.txt').then(function(stats) {
       assert.isTrue(stats.isFile());
       assert.isFalse(stats.isSymbolicLink());
@@ -76,6 +120,15 @@ describe('fs.lstat(path, callback)', function() {
     }, done);
   });
 
+  it('promise stats a regular file with bigint', function(done) {
+    fs.promises.lstat('file.txt', {bigint: true}).then(function(stats) {
+      assert.isTrue(stats.isFile());
+      assert.isFalse(stats.isSymbolicLink());
+      assert.equal(typeof stats.mtimeMs, 'bigint');
+      done();
+    }, done);
+  });
+
   it('fails on file not exist', function(done) {
     fs.lstat('bogus', function(err, stats) {
       assert.instanceOf(err, Error);
@@ -84,11 +137,10 @@ describe('fs.lstat(path, callback)', function() {
     });
   });
 
-  withPromise.it('promise fails on file not exist', function(done) {
+  it('promise fails on file not exist', function(done) {
     fs.promises.lstat('bogus').then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -99,7 +151,7 @@ describe('fs.lstat(path, callback)', function() {
   });
 });
 
-describe('fs.lstatSync(path)', function() {
+describe('fs.lstatSync(path, options)', function() {
   beforeEach(function() {
     mock({
       'file.txt': mock.file({
@@ -121,6 +173,13 @@ describe('fs.lstatSync(path)', function() {
     assert.equal(stats.mtime.getTime(), 2);
   });
 
+  it('stats a symbolic link with bigint', function() {
+    const stats = fs.lstatSync('link', {bigint: true});
+    assert.isTrue(stats.isSymbolicLink());
+    assert.isFalse(stats.isFile());
+    assert.equal(typeof stats.mtimeMs, 'bigint');
+  });
+
   it('stats a regular file', function() {
     const stats = fs.lstatSync('file.txt');
     assert.isTrue(stats.isFile());
@@ -128,6 +187,13 @@ describe('fs.lstatSync(path)', function() {
     assert.equal(stats.mtime.getTime(), 1);
   });
 
+  it('stats a regular file with bigint', function() {
+    const stats = fs.lstatSync('file.txt', {bigint: true});
+    assert.isTrue(stats.isFile());
+    assert.isFalse(stats.isSymbolicLink());
+    assert.equal(typeof stats.mtimeMs, 'bigint');
+  });
+
   it('fails on file not exist', function() {
     assert.throws(function() {
       fs.lstatSync('bogus');
