@@ -5,11 +5,8 @@ const fs = require('fs');
 const mock = require('../../lib/index');
 
 const assert = helper.assert;
-const inVersion = helper.inVersion;
-const withPromise = helper.withPromise;
 
-const testParentPerms =
-  fs.access && fs.accessSync && process.getuid && process.getgid;
+const testParentPerms = process.getuid && process.getgid;
 
 describe('fs.mkdir(path, [mode], callback)', function() {
   beforeEach(function() {
@@ -46,7 +43,7 @@ describe('fs.mkdir(path, [mode], callback)', function() {
     });
   });
 
-  withPromise.it('promise creates a new directory', function(done) {
+  it('promise creates a new directory', function(done) {
     fs.promises.mkdir('parent/dir').then(function() {
       const stats = fs.statSync('parent/dir');
       assert.isTrue(stats.isDirectory());
@@ -54,9 +51,7 @@ describe('fs.mkdir(path, [mode], callback)', function() {
     }, done);
   });
 
-  inVersion('>=10.12').it('creates a new directory recursively', function(
-    done
-  ) {
+  it('creates a new directory recursively', function(done) {
     fs.mkdir('parent/foo/bar/dir', {recursive: true}, function(err) {
       if (err) {
         return done(err);
@@ -71,7 +66,7 @@ describe('fs.mkdir(path, [mode], callback)', function() {
     });
   });
 
-  withPromise.it('promise creates a new directory recursively', function(done) {
+  it('promise creates a new directory recursively', function(done) {
     fs.promises.mkdir('parent/foo/bar/dir', {recursive: true}).then(function() {
       let stats = fs.statSync('parent/foo/bar/dir');
       assert.isTrue(stats.isDirectory());
@@ -95,7 +90,7 @@ describe('fs.mkdir(path, [mode], callback)', function() {
     });
   });
 
-  withPromise.it('promise accepts dir mode', function(done) {
+  it('promise accepts dir mode', function(done) {
     fs.promises.mkdir('parent/dir', parseInt('0755', 8)).then(function() {
       const stats = fs.statSync('parent/dir');
       assert.isTrue(stats.isDirectory());
@@ -104,7 +99,7 @@ describe('fs.mkdir(path, [mode], callback)', function() {
     }, done);
   });
 
-  inVersion('>=10.12').it('accepts dir mode recursively', function(done) {
+  it('accepts dir mode recursively', function(done) {
     fs.mkdir(
       'parent/foo/bar/dir',
       {recursive: true, mode: parseInt('0755', 8)},
@@ -128,7 +123,7 @@ describe('fs.mkdir(path, [mode], callback)', function() {
     );
   });
 
-  withPromise.it('promise accepts dir mode recursively', function(done) {
+  it('promise accepts dir mode recursively', function(done) {
     fs.promises
       .mkdir('parent/foo/bar/dir', {recursive: true, mode: parseInt('0755', 8)})
       .then(function() {
@@ -155,11 +150,10 @@ describe('fs.mkdir(path, [mode], callback)', function() {
     });
   });
 
-  withPromise.it('promise fails if parent does not exist', function(done) {
+  it('promise fails if parent does not exist', function(done) {
     fs.promises.mkdir('parent/bogus/dir').then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -169,66 +163,52 @@ describe('fs.mkdir(path, [mode], callback)', function() {
     );
   });
 
-  inVersion('>=10.12').it(
-    'fails if one parent is not a folder in recursive creation',
-    function(done) {
-      fs.mkdir('file.txt/bogus/dir', {recursive: true}, function(err) {
+  it('fails if one parent is not a folder in recursive creation', function(done) {
+    fs.mkdir('file.txt/bogus/dir', {recursive: true}, function(err) {
+      assert.instanceOf(err, Error);
+      done();
+    });
+  });
+
+  it('promise fails if one parent is not a folder in recursive creation', function(done) {
+    fs.promises.mkdir('file.txt/bogus/dir', {recursive: true}).then(
+      function() {
+        done(new Error('should not succeed.'));
+      },
+      function(err) {
         assert.instanceOf(err, Error);
         done();
-      });
-    }
-  );
+      }
+    );
+  });
 
-  withPromise.it(
-    'promise fails if one parent is not a folder in recursive creation',
-    function(done) {
-      fs.promises.mkdir('file.txt/bogus/dir', {recursive: true}).then(
+  it('fails if permission does not allow recursive creation', function(done) {
+    fs.mkdir(
+      'parent/foo/bar/dir',
+      {recursive: true, mode: parseInt('0400', 8)},
+      function(err) {
+        assert.instanceOf(err, Error);
+        done();
+      }
+    );
+  });
+
+  it('promise fails if permission does not allow recursive creation', function(done) {
+    fs.promises
+      .mkdir('parent/foo/bar/dir', {
+        recursive: true,
+        mode: parseInt('0400', 8)
+      })
+      .then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
           done();
         }
       );
-    }
-  );
-
-  inVersion('>=10.12').it(
-    'fails if permission does not allow recursive creation',
-    function(done) {
-      fs.mkdir(
-        'parent/foo/bar/dir',
-        {recursive: true, mode: parseInt('0400', 8)},
-        function(err) {
-          assert.instanceOf(err, Error);
-          done();
-        }
-      );
-    }
-  );
-
-  withPromise.it(
-    'promise fails if permission does not allow recursive creation',
-    function(done) {
-      fs.promises
-        .mkdir('parent/foo/bar/dir', {
-          recursive: true,
-          mode: parseInt('0400', 8)
-        })
-        .then(
-          function() {
-            assert.fail('should not succeed.');
-            done();
-          },
-          function(err) {
-            assert.instanceOf(err, Error);
-            done();
-          }
-        );
-    }
-  );
+  });
 
   it('fails if directory already exists', function(done) {
     fs.mkdir('parent', function(err) {
@@ -238,11 +218,10 @@ describe('fs.mkdir(path, [mode], callback)', function() {
     });
   });
 
-  withPromise.it('promise fails if directory already exists', function(done) {
+  it('promise fails if directory already exists', function(done) {
     fs.promises.mkdir('parent').then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -260,11 +239,10 @@ describe('fs.mkdir(path, [mode], callback)', function() {
     });
   });
 
-  withPromise.it('promise fails if file already exists', function(done) {
+  it('promise fails if file already exists', function(done) {
     fs.promises.mkdir('file.txt').then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -274,50 +252,37 @@ describe('fs.mkdir(path, [mode], callback)', function() {
     );
   });
 
-  inVersion('>=10.12').it(
-    'fails in recursive mode if file already exists',
-    function(done) {
-      fs.mkdir('parent/file.md', {recursive: true}, function(err) {
+  it('fails in recursive mode if file already exists', function(done) {
+    fs.mkdir('parent/file.md', {recursive: true}, function(err) {
+      assert.instanceOf(err, Error);
+      assert.equal(err.code, 'EEXIST');
+      done();
+    });
+  });
+
+  it('promise fails in recursive mode if file already exists', function(done) {
+    fs.promises.mkdir('parent/file.md', {recursive: true}).then(
+      function() {
+        done(new Error('should not succeed.'));
+      },
+      function(err) {
         assert.instanceOf(err, Error);
         assert.equal(err.code, 'EEXIST');
         done();
-      });
-    }
-  );
+      }
+    );
+  });
 
-  withPromise.it(
-    'promise fails in recursive mode if file already exists',
-    function(done) {
-      fs.promises.mkdir('parent/file.md', {recursive: true}).then(
-        function() {
-          assert.fail('should not succeed.');
-          done();
-        },
-        function(err) {
-          assert.instanceOf(err, Error);
-          assert.equal(err.code, 'EEXIST');
-          done();
-        }
-      );
-    }
-  );
+  it('passes in recursive mode if directory already exists', function(done) {
+    fs.mkdir('parent/child', {recursive: true}, function(err) {
+      assert.isNotOk(err, Error);
+      done();
+    });
+  });
 
-  inVersion('>=10.12').it(
-    'passes in recursive mode if directory already exists',
-    function(done) {
-      fs.mkdir('parent/child', {recursive: true}, function(err) {
-        assert.isNotOk(err, Error);
-        done();
-      });
-    }
-  );
-
-  withPromise.it(
-    'promise passes in recursive mode if directory already exists',
-    function(done) {
-      fs.promises.mkdir('parent/child', {recursive: true}).then(done, done);
-    }
-  );
+  it('promise passes in recursive mode if directory already exists', function(done) {
+    fs.promises.mkdir('parent/child', {recursive: true}).then(done, done);
+  });
 
   if (testParentPerms) {
     it('fails if parent is not writeable', function(done) {
@@ -328,11 +293,10 @@ describe('fs.mkdir(path, [mode], callback)', function() {
       });
     });
 
-    withPromise.it('promise fails if parent is not writeable', function(done) {
+    it('promise fails if parent is not writeable', function(done) {
       fs.promises.mkdir('unwriteable/child').then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
@@ -377,7 +341,7 @@ describe('fs.mkdirSync(path, [mode])', function() {
     assert.isTrue(stats.isDirectory());
   });
 
-  inVersion('>=10.12').it('creates a new directory recursively', function() {
+  it('creates a new directory recursively', function() {
     fs.mkdirSync('parent/foo/bar/dir', {recursive: true});
     let stats = fs.statSync('parent/foo/bar/dir');
     assert.isTrue(stats.isDirectory());
@@ -394,7 +358,7 @@ describe('fs.mkdirSync(path, [mode])', function() {
     assert.equal(stats.mode & parseInt('0777', 8), parseInt('0755', 8));
   });
 
-  inVersion('>=10.12').it('accepts dir mode recursively', function() {
+  it('accepts dir mode recursively', function() {
     fs.mkdirSync('parent/foo/bar/dir', {
       recursive: true,
       mode: parseInt('0755', 8)
@@ -418,26 +382,20 @@ describe('fs.mkdirSync(path, [mode])', function() {
     });
   });
 
-  inVersion('>=10.12').it(
-    'fails if one parent is not a folder in recursive creation',
-    function() {
-      assert.throws(function() {
-        fs.mkdirSync('file.txt/bogus/dir', {recursive: true});
-      });
-    }
-  );
+  it('fails if one parent is not a folder in recursive creation', function() {
+    assert.throws(function() {
+      fs.mkdirSync('file.txt/bogus/dir', {recursive: true});
+    });
+  });
 
-  inVersion('>=10.12').it(
-    'fails if permission does not allow recursive creation',
-    function() {
-      assert.throws(function() {
-        fs.mkdirSync('parent/foo/bar/dir', {
-          recursive: true,
-          mode: parseInt('0400', 8)
-        });
+  it('fails if permission does not allow recursive creation', function() {
+    assert.throws(function() {
+      fs.mkdirSync('parent/foo/bar/dir', {
+        recursive: true,
+        mode: parseInt('0400', 8)
       });
-    }
-  );
+    });
+  });
 
   it('fails if directory already exists', function() {
     assert.throws(function() {
@@ -451,23 +409,17 @@ describe('fs.mkdirSync(path, [mode])', function() {
     });
   });
 
-  inVersion('>=10.12').it(
-    'fails in recursive mode if file already exists',
-    function() {
-      assert.throws(function() {
-        fs.mkdirSync('parent/file.md', {recursive: true});
-      });
-    }
-  );
+  it('fails in recursive mode if file already exists', function() {
+    assert.throws(function() {
+      fs.mkdirSync('parent/file.md', {recursive: true});
+    });
+  });
 
-  inVersion('>=10.12').it(
-    'passes in recursive mode if directory already exists',
-    function() {
-      assert.doesNotThrow(function() {
-        fs.mkdirSync('parent/child', {recursive: true});
-      });
-    }
-  );
+  it('passes in recursive mode if directory already exists', function() {
+    assert.doesNotThrow(function() {
+      fs.mkdirSync('parent/child', {recursive: true});
+    });
+  });
 
   if (testParentPerms) {
     it('fails if parent is not writeable', function() {
