@@ -5,7 +5,7 @@ const fs = require('fs');
 const mock = require('../../lib/index');
 
 const assert = helper.assert;
-const withPromise = helper.withPromise;
+const inVersion = helper.inVersion;
 
 describe('fs.open(path, flags, [mode], callback)', function() {
   beforeEach(function() {
@@ -44,9 +44,7 @@ describe('fs.open(path, flags, [mode], callback)', function() {
     });
   });
 
-  withPromise.it('promise opens an existing file for reading (r)', function(
-    done
-  ) {
+  it('promise opens an existing file for reading (r)', function(done) {
     fs.promises.open('nested/sub/dir/one.txt', 'r').then(function(fd) {
       assert.isNumber(fd.fd);
       done();
@@ -61,11 +59,10 @@ describe('fs.open(path, flags, [mode], callback)', function() {
     });
   });
 
-  withPromise.it('promise fails if file does not exist (r)', function(done) {
+  it('promise fails if file does not exist (r)', function(done) {
     fs.promises.open('bogus.txt', 'r').then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -86,7 +83,7 @@ describe('fs.open(path, flags, [mode], callback)', function() {
     });
   });
 
-  withPromise.it('promise creates a new file for writing (w)', function(done) {
+  it('promise creates a new file for writing (w)', function(done) {
     fs.promises
       .open('path/to/new.txt', 'w', parseInt('0666', 8))
       .then(function(fd) {
@@ -106,9 +103,7 @@ describe('fs.open(path, flags, [mode], callback)', function() {
     });
   });
 
-  withPromise.it('promise opens an existing file for writing (w)', function(
-    done
-  ) {
+  it('promise opens an existing file for writing (w)', function(done) {
     fs.promises
       .open('path/to/file.txt', 'w', parseInt('0666', 8))
       .then(function(fd) {
@@ -125,11 +120,10 @@ describe('fs.open(path, flags, [mode], callback)', function() {
     });
   });
 
-  withPromise.it('promise fails if file exists (wx)', function(done) {
+  it('promise fails if file exists (wx)', function(done) {
     fs.promises.open('path/to/file.txt', 'wx', parseInt('0666', 8)).then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -199,7 +193,7 @@ describe('fs.close(fd, callback)', function() {
     });
   });
 
-  withPromise.it('promise closes a file descriptor', function(done) {
+  it('promise closes a file descriptor', function(done) {
     fs.promises
       .open('dir/file.txt', 'w')
       .then(function(fd) {
@@ -222,18 +216,20 @@ describe('fs.close(fd, callback)', function() {
     });
   });
 
-  withPromise.it('promise fails for closed file descriptors', function(done) {
+  inVersion('<14.0.0').it('promise fails for closed file descriptors', function(
+    done
+  ) {
     fs.promises
       .open('dir/file.txt', 'w')
       .then(function(fd) {
         return fd.close().then(function() {
+          // in Nodejs v14+, closing on closed file descriptor is silently ignored.
           return fd.close();
         });
       })
       .then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
