@@ -5,7 +5,6 @@ const fs = require('fs');
 const mock = require('../../lib/index');
 
 const assert = helper.assert;
-const withPromise = helper.withPromise;
 
 describe('fs.readFile(filename, [options], callback)', function() {
   // this is provided by fs.open, fs.fstat, and fs.read
@@ -29,9 +28,7 @@ describe('fs.readFile(filename, [options], callback)', function() {
     });
   });
 
-  withPromise.it('promise allows a file to be read asynchronously', function(
-    done
-  ) {
+  it('promise allows a file to be read asynchronously', function(done) {
     fs.promises.readFile('path/to/file.txt').then(function(data) {
       assert.isTrue(Buffer.isBuffer(data));
       assert.equal(String(data), 'file content');
@@ -47,11 +44,10 @@ describe('fs.readFile(filename, [options], callback)', function() {
     });
   });
 
-  withPromise.it('promise fails for directory', function(done) {
+  it('promise fails for directory', function(done) {
     fs.promises.readFile('path/to').then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -70,11 +66,10 @@ describe('fs.readFile(filename, [options], callback)', function() {
     });
   });
 
-  withPromise.it('promise fails for bad path', function(done) {
+  it('promise fails for bad path', function(done) {
     fs.promises.readFile('path/to/bogus').then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
