@@ -6,8 +6,6 @@ const mock = require('../../lib/index');
 const path = require('path');
 
 const assert = helper.assert;
-const withPromise = helper.withPromise;
-const inVersion = helper.inVersion;
 
 describe('fs.readdir(path, callback)', function() {
   beforeEach(function() {
@@ -52,7 +50,7 @@ describe('fs.readdir(path, callback)', function() {
     });
   });
 
-  withPromise.it('promise lists directory contents', function(done) {
+  it('promise lists directory contents', function(done) {
     fs.promises.readdir(path.join('path', 'to')).then(function(items) {
       assert.isArray(items);
       assert.deepEqual(items, ['file.txt']);
@@ -69,7 +67,7 @@ describe('fs.readdir(path, callback)', function() {
     });
   });
 
-  withPromise.it('promise lists nested directory contents', function(done) {
+  it('promise lists nested directory contents', function(done) {
     fs.promises
       .readdir(path.join('nested', 'sub', 'dir'))
       .then(function(items) {
@@ -87,11 +85,10 @@ describe('fs.readdir(path, callback)', function() {
     });
   });
 
-  withPromise.it('promise calls with an error for bogus path', function(done) {
+  it('promise calls with an error for bogus path', function(done) {
     fs.promises.readdir('bogus').then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -109,13 +106,10 @@ describe('fs.readdir(path, callback)', function() {
     });
   });
 
-  withPromise.it('promise calls with an error for restricted path', function(
-    done
-  ) {
+  it('promise calls with an error for restricted path', function(done) {
     fs.promises.readdir('denied').then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -125,20 +119,17 @@ describe('fs.readdir(path, callback)', function() {
     );
   });
 
-  inVersion('>=10.10').it('should support "withFileTypes" option', function(
-    done
-  ) {
+  it('should support "withFileTypes" option', function(done) {
     fs.readdir(
       path.join('nested', 'sub', 'dir'),
       {withFileTypes: true},
       function(err, items) {
         assert.isNull(err);
         assert.isArray(items);
-        assert.deepEqual(items, [
-          {name: 'empty'},
-          {name: 'one.txt'},
-          {name: 'two.txt'}
-        ]);
+        assert.deepEqual(
+          items.map(i => i.name),
+          ['empty', 'one.txt', 'two.txt']
+        );
         assert.ok(items[0].isDirectory());
         assert.ok(items[1].isFile());
         assert.ok(items[2].isFile());
@@ -147,16 +138,15 @@ describe('fs.readdir(path, callback)', function() {
     );
   });
 
-  withPromise.it('should support "withFileTypes" option', function(done) {
+  it('should support "withFileTypes" option', function(done) {
     fs.promises
       .readdir(path.join('nested', 'sub', 'dir'), {withFileTypes: true})
       .then(function(items) {
         assert.isArray(items);
-        assert.deepEqual(items, [
-          {name: 'empty'},
-          {name: 'one.txt'},
-          {name: 'two.txt'}
-        ]);
+        assert.deepEqual(
+          items.map(i => i.name),
+          ['empty', 'one.txt', 'two.txt']
+        );
         assert.ok(items[0].isDirectory());
         assert.ok(items[1].isFile());
         assert.ok(items[2].isFile());
@@ -164,55 +154,49 @@ describe('fs.readdir(path, callback)', function() {
       }, done);
   });
 
-  inVersion('>=10.10').it(
-    'should support "withFileTypes" option with "encoding" option',
-    function(done) {
-      fs.readdir(
-        path.join('nested', 'sub', 'dir'),
-        {withFileTypes: true, encoding: 'buffer'},
-        function(err, items) {
-          assert.isNull(err);
-          assert.isArray(items);
-          items.forEach(function(item) {
-            assert.equal(Buffer.isBuffer(item.name), true);
-          });
-          const names = items.map(function(item) {
-            return item.name.toString();
-          });
-          assert.deepEqual(names, ['empty', 'one.txt', 'two.txt']);
-          assert.ok(items[0].isDirectory());
-          assert.ok(items[1].isFile());
-          assert.ok(items[2].isFile());
-          done();
-        }
-      );
-    }
-  );
-
-  withPromise.it(
-    'should support "withFileTypes" option with "encoding" option',
-    function(done) {
-      fs.promises
-        .readdir(path.join('nested', 'sub', 'dir'), {
-          withFileTypes: true,
-          encoding: 'buffer'
-        })
-        .then(function(items) {
-          assert.isArray(items);
-          items.forEach(function(item) {
-            assert.equal(Buffer.isBuffer(item.name), true);
-          });
-          const names = items.map(function(item) {
-            return item.name.toString();
-          });
-          assert.deepEqual(names, ['empty', 'one.txt', 'two.txt']);
-          assert.ok(items[0].isDirectory());
-          assert.ok(items[1].isFile());
-          assert.ok(items[2].isFile());
-          done();
+  it('should support "withFileTypes" option with "encoding" option', function(done) {
+    fs.readdir(
+      path.join('nested', 'sub', 'dir'),
+      {withFileTypes: true, encoding: 'buffer'},
+      function(err, items) {
+        assert.isNull(err);
+        assert.isArray(items);
+        items.forEach(function(item) {
+          assert.equal(Buffer.isBuffer(item.name), true);
         });
-    }
-  );
+        const names = items.map(function(item) {
+          return item.name.toString();
+        });
+        assert.deepEqual(names, ['empty', 'one.txt', 'two.txt']);
+        assert.ok(items[0].isDirectory());
+        assert.ok(items[1].isFile());
+        assert.ok(items[2].isFile());
+        done();
+      }
+    );
+  });
+
+  it('should support "withFileTypes" option with "encoding" option', function(done) {
+    fs.promises
+      .readdir(path.join('nested', 'sub', 'dir'), {
+        withFileTypes: true,
+        encoding: 'buffer'
+      })
+      .then(function(items) {
+        assert.isArray(items);
+        items.forEach(function(item) {
+          assert.equal(Buffer.isBuffer(item.name), true);
+        });
+        const names = items.map(function(item) {
+          return item.name.toString();
+        });
+        assert.deepEqual(names, ['empty', 'one.txt', 'two.txt']);
+        assert.ok(items[0].isDirectory());
+        assert.ok(items[1].isFile());
+        assert.ok(items[2].isFile());
+        done();
+      });
+  });
 });
 
 describe('fs.readdirSync(path)', function() {
