@@ -5,7 +5,6 @@ const fs = require('fs');
 const mock = require('../../lib/index');
 
 const assert = helper.assert;
-const withPromise = helper.withPromise;
 
 describe('fs.readlink(path, callback)', function() {
   beforeEach(function() {
@@ -36,7 +35,7 @@ describe('fs.readlink(path, callback)', function() {
     });
   });
 
-  withPromise.it('promise reads a symbolic link', function(done) {
+  it('promise reads a symbolic link', function(done) {
     fs.promises.readlink('link').then(function(srcPath) {
       assert.equal(srcPath, './file.txt');
       done();
@@ -50,11 +49,10 @@ describe('fs.readlink(path, callback)', function() {
     });
   });
 
-  withPromise.it('promise fails for regular files', function(done) {
+  it('promise fails for regular files', function(done) {
     fs.promises.readlink('file.txt').then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
