@@ -3,15 +3,13 @@
 const helper = require('../helper');
 const fs = require('fs');
 const mock = require('../../lib/index');
-const bufferFrom = require('../../lib/buffer').from;
 
 const assert = helper.assert;
-const withPromise = helper.withPromise;
 
 describe('fs.rename(oldPath, newPath, callback)', function() {
   beforeEach(function() {
     mock({
-      'path/to/a.bin': bufferFrom([1, 2, 3]),
+      'path/to/a.bin': Buffer.from([1, 2, 3]),
       empty: {},
       nested: {
         dir: mock.directory({
@@ -45,7 +43,7 @@ describe('fs.rename(oldPath, newPath, callback)', function() {
     );
   });
 
-  withPromise.it('promise allows files to be renamed', function(done) {
+  it('promise allows files to be renamed', function(done) {
     fs.promises.rename('path/to/a.bin', 'path/to/b.bin').then(function() {
       assert.isFalse(fs.existsSync('path/to/a.bin'));
       assert.isTrue(fs.existsSync('path/to/b.bin'));
@@ -65,7 +63,7 @@ describe('fs.rename(oldPath, newPath, callback)', function() {
     });
   });
 
-  withPromise.it('promise updates mtime of parent directory', function(done) {
+  it('promise updates mtime of parent directory', function(done) {
     const oldTime = fs.statSync('nested/dir').mtime;
     fs.promises
       .rename('nested/dir/file.txt', 'nested/dir/renamed.txt')
@@ -85,21 +83,17 @@ describe('fs.rename(oldPath, newPath, callback)', function() {
     });
   });
 
-  withPromise.it(
-    'promise calls callback with error if old path does not exist',
-    function(done) {
-      fs.promises.rename('bogus', 'empty').then(
-        function() {
-          assert.fail('Should not succeed.');
-          done();
-        },
-        function(err) {
-          assert.instanceOf(err, Error);
-          done();
-        }
-      );
-    }
-  );
+  it('promise calls callback with error if old path does not exist', function(done) {
+    fs.promises.rename('bogus', 'empty').then(
+      function() {
+        done(new Error('Should not succeed.'));
+      },
+      function(err) {
+        assert.instanceOf(err, Error);
+        done();
+      }
+    );
+  });
 
   it('overwrites existing files', function(done) {
     fs.rename('path/to/a.bin', 'nested/dir/file.txt', function(err) {
@@ -110,7 +104,7 @@ describe('fs.rename(oldPath, newPath, callback)', function() {
     });
   });
 
-  withPromise.it('promise overwrites existing files', function(done) {
+  it('promise overwrites existing files', function(done) {
     fs.promises.rename('path/to/a.bin', 'nested/dir/file.txt').then(function() {
       assert.isFalse(fs.existsSync('path/to/a.bin'));
       assert.isTrue(fs.existsSync('nested/dir/file.txt'));
@@ -128,7 +122,7 @@ describe('fs.rename(oldPath, newPath, callback)', function() {
     });
   });
 
-  withPromise.it('promise allows directories to be renamed', function(done) {
+  it('promise allows directories to be renamed', function(done) {
     fs.promises.rename('path/to', 'path/foo').then(function() {
       assert.isFalse(fs.existsSync('path/to'));
       assert.isTrue(fs.existsSync('path/foo'));
@@ -144,27 +138,23 @@ describe('fs.rename(oldPath, newPath, callback)', function() {
     });
   });
 
-  withPromise.it(
-    'promise calls callback with error if new directory not empty',
-    function(done) {
-      fs.promises.rename('path', 'nested').then(
-        function() {
-          assert.fail('Should not succeed.');
-          done();
-        },
-        function(err) {
-          assert.instanceOf(err, Error);
-          done();
-        }
-      );
-    }
-  );
+  it('promise calls callback with error if new directory not empty', function(done) {
+    fs.promises.rename('path', 'nested').then(
+      function() {
+        done(new Error('Should not succeed.'));
+      },
+      function(err) {
+        assert.instanceOf(err, Error);
+        done();
+      }
+    );
+  });
 });
 
 describe('fs.renameSync(oldPath, newPath)', function() {
   beforeEach(function() {
     mock({
-      'path/to/a.bin': bufferFrom([1, 2, 3]),
+      'path/to/a.bin': Buffer.from([1, 2, 3]),
       empty: {},
       nested: {
         dir: {
