@@ -6,10 +6,8 @@ const mock = require('../../lib/index');
 
 const assert = helper.assert;
 const inVersion = helper.inVersion;
-const withPromise = helper.withPromise;
 
-const testParentPerms =
-  fs.access && fs.accessSync && process.getuid && process.getgid;
+const testParentPerms = process.getuid && process.getgid;
 
 function setup() {
   mock({
@@ -63,7 +61,7 @@ describe('fs.rmdir(path, callback)', function() {
     });
   });
 
-  withPromise.it('promise removes an empty directory', function(done) {
+  it('promise removes an empty directory', function(done) {
     assert.equal(fs.statSync('path/to').nlink, 3);
 
     fs.promises.rmdir('path/to/empty').then(function() {
@@ -81,11 +79,10 @@ describe('fs.rmdir(path, callback)', function() {
     });
   });
 
-  withPromise.it('promise fails if not empty', function(done) {
+  it('promise fails if not empty', function(done) {
     fs.promises.rmdir('path/to').then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -103,11 +100,10 @@ describe('fs.rmdir(path, callback)', function() {
     });
   });
 
-  withPromise.it('promise fails if file', function(done) {
+  it('promise fails if file', function(done) {
     fs.promises.rmdir('file.txt').then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -176,11 +172,10 @@ describe('fs.rmdir(path, callback)', function() {
       });
     });
 
-    withPromise.it('promise fails if parent is not writeable', function(done) {
+    it('promise fails if parent is not writeable', function(done) {
       fs.promises.rmdir('unwriteable/child').then(
         function() {
-          assert.fail('should not succeed.');
-          done();
+          done(new Error('should not succeed.'));
         },
         function(err) {
           assert.instanceOf(err, Error);
