@@ -5,7 +5,6 @@ const fs = require('fs');
 const mock = require('../../lib/index');
 
 const assert = helper.assert;
-const withPromise = helper.withPromise;
 
 describe('fs.utimes(path, atime, mtime, callback)', function() {
   beforeEach(function() {
@@ -42,7 +41,7 @@ describe('fs.utimes(path, atime, mtime, callback)', function() {
     });
   });
 
-  withPromise.it('promise updates timestamps for a file', function(done) {
+  it('promise updates timestamps for a file', function(done) {
     fs.promises
       .utimes('file.txt', new Date(100), new Date(200))
       .then(function() {
@@ -65,7 +64,7 @@ describe('fs.utimes(path, atime, mtime, callback)', function() {
     });
   });
 
-  withPromise.it('promise updates timestamps for a directory', function(done) {
+  it('promise updates timestamps for a directory', function(done) {
     fs.promises.utimes('dir', new Date(300), new Date(400)).then(function() {
       const stats = fs.statSync('dir');
       assert.equal(stats.atime.getTime(), 300);
@@ -82,11 +81,10 @@ describe('fs.utimes(path, atime, mtime, callback)', function() {
     });
   });
 
-  withPromise.it('promise fails for a bogus path', function(done) {
+  it('promise fails for a bogus path', function(done) {
     fs.promises.utimes('bogus.txt', new Date(100), new Date(200)).then(
       function() {
-        assert.fail('should not succeed.');
-        done();
+        done(new Error('should not succeed.'));
       },
       function(err) {
         assert.instanceOf(err, Error);
@@ -135,7 +133,7 @@ describe('fs.futimes(fd, atime, mtime, callback)', function() {
     });
   });
 
-  withPromise.it('promise updates timestamps for a file', function(done) {
+  it('promise updates timestamps for a file', function(done) {
     fs.promises
       .open('file.txt', 'r')
       .then(function(fd) {
@@ -162,7 +160,7 @@ describe('fs.futimes(fd, atime, mtime, callback)', function() {
     });
   });
 
-  withPromise.it('promise updates timestamps for a directory', function(done) {
+  it('promise updates timestamps for a directory', function(done) {
     fs.promises
       .open('dir', 'r')
       .then(function(fd) {
